==> zio-aws-emr_2.12-5.17.129.3-sources.jar: zio/aws/emr/model/CreateStudioSessionMappingRequest.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.XmlStringMaxLen256
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateStudioSessionMappingRequest(
    studioId: XmlStringMaxLen256,
    identityId: Option[XmlStringMaxLen256] = None,
    identityName: Option[XmlStringMaxLen256] = None,
    identityType: zio.aws.emr.model.IdentityType,
    sessionPolicyArn: XmlStringMaxLen256
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest = {
    import CreateStudioSessionMappingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
      .builder()
      .studioId(XmlStringMaxLen256.unwrap(studioId): java.lang.String)
      .optionallyWith(
        identityId.map(value =>
          XmlStringMaxLen256.unwrap(value): java.lang.String
        )
      )(_.identityId)
      .optionallyWith(
        identityName.map(value =>
          XmlStringMaxLen256.unwrap(value): java.lang.String
        )
      )(_.identityName)
      .identityType(identityType.unwrap)
      .sessionPolicyArn(
        XmlStringMaxLen256.unwrap(sessionPolicyArn): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.emr.model.CreateStudioSessionMappingRequest.ReadOnly =
    zio.aws.emr.model.CreateStudioSessionMappingRequest.wrap(buildAwsValue())
}
object CreateStudioSessionMappingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.CreateStudioSessionMappingRequest =
      zio.aws.emr.model.CreateStudioSessionMappingRequest(
        studioId,
        identityId.map(value => value),
        identityName.map(value => value),
        identityType,
        sessionPolicyArn
      )
    def studioId: XmlStringMaxLen256
    def identityId: Option[XmlStringMaxLen256]
    def identityName: Option[XmlStringMaxLen256]
    def identityType: zio.aws.emr.model.IdentityType
    def sessionPolicyArn: XmlStringMaxLen256
    def getStudioId: ZIO[Any, Nothing, XmlStringMaxLen256] =
      ZIO.succeed(studioId)
    def getIdentityId: ZIO[Any, AwsError, XmlStringMaxLen256] =
      AwsError.unwrapOptionField("identityId", identityId)
    def getIdentityName: ZIO[Any, AwsError, XmlStringMaxLen256] =
      AwsError.unwrapOptionField("identityName", identityName)
    def getIdentityType: ZIO[Any, Nothing, zio.aws.emr.model.IdentityType] =
      ZIO.succeed(identityType)
    def getSessionPolicyArn: ZIO[Any, Nothing, XmlStringMaxLen256] =
      ZIO.succeed(sessionPolicyArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
  ) extends zio.aws.emr.model.CreateStudioSessionMappingRequest.ReadOnly {
    override val studioId: XmlStringMaxLen256 =
      zio.aws.emr.model.primitives.XmlStringMaxLen256(impl.studioId())
    override val identityId: Option[XmlStringMaxLen256] = scala
      .Option(impl.identityId())
      .map(value => zio.aws.emr.model.primitives.XmlStringMaxLen256(value))
    override val identityName: Option[XmlStringMaxLen256] = scala
      .Option(impl.identityName())
      .map(value => zio.aws.emr.model.primitives.XmlStringMaxLen256(value))
    override val identityType: zio.aws.emr.model.IdentityType =
      zio.aws.emr.model.IdentityType.wrap(impl.identityType())
    override val sessionPolicyArn: XmlStringMaxLen256 =
      zio.aws.emr.model.primitives.XmlStringMaxLen256(impl.sessionPolicyArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
  ): zio.aws.emr.model.CreateStudioSessionMappingRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-emr_2.13-7.28.24.2-sources.jar: zio/aws/emr/model/CreateStudioSessionMappingRequest.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.XmlStringMaxLen256
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateStudioSessionMappingRequest(
    studioId: XmlStringMaxLen256,
    identityId: Optional[XmlStringMaxLen256] = Optional.Absent,
    identityName: Optional[XmlStringMaxLen256] = Optional.Absent,
    identityType: zio.aws.emr.model.IdentityType,
    sessionPolicyArn: XmlStringMaxLen256
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest = {
    import CreateStudioSessionMappingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
      .builder()
      .studioId(XmlStringMaxLen256.unwrap(studioId): java.lang.String)
      .optionallyWith(
        identityId.map(value =>
          XmlStringMaxLen256.unwrap(value): java.lang.String
        )
      )(_.identityId)
      .optionallyWith(
        identityName.map(value =>
          XmlStringMaxLen256.unwrap(value): java.lang.String
        )
      )(_.identityName)
      .identityType(identityType.unwrap)
      .sessionPolicyArn(
        XmlStringMaxLen256.unwrap(sessionPolicyArn): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.emr.model.CreateStudioSessionMappingRequest.ReadOnly =
    zio.aws.emr.model.CreateStudioSessionMappingRequest.wrap(buildAwsValue())
}
object CreateStudioSessionMappingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.CreateStudioSessionMappingRequest =
      zio.aws.emr.model.CreateStudioSessionMappingRequest(
        studioId,
        identityId.map(value => value),
        identityName.map(value => value),
        identityType,
        sessionPolicyArn
      )
    def studioId: XmlStringMaxLen256
    def identityId: Optional[XmlStringMaxLen256]
    def identityName: Optional[XmlStringMaxLen256]
    def identityType: zio.aws.emr.model.IdentityType
    def sessionPolicyArn: XmlStringMaxLen256
    def getStudioId: ZIO[Any, Nothing, XmlStringMaxLen256] =
      ZIO.succeed(studioId)
    def getIdentityId: ZIO[Any, AwsError, XmlStringMaxLen256] =
      AwsError.unwrapOptionField("identityId", identityId)
    def getIdentityName: ZIO[Any, AwsError, XmlStringMaxLen256] =
      AwsError.unwrapOptionField("identityName", identityName)
    def getIdentityType: ZIO[Any, Nothing, zio.aws.emr.model.IdentityType] =
      ZIO.succeed(identityType)
    def getSessionPolicyArn: ZIO[Any, Nothing, XmlStringMaxLen256] =
      ZIO.succeed(sessionPolicyArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
  ) extends zio.aws.emr.model.CreateStudioSessionMappingRequest.ReadOnly {
    override val studioId: XmlStringMaxLen256 =
      zio.aws.emr.model.primitives.XmlStringMaxLen256(impl.studioId())
    override val identityId: Optional[XmlStringMaxLen256] =
      zio.aws.core.internal
        .optionalFromNullable(impl.identityId())
        .map(value => zio.aws.emr.model.primitives.XmlStringMaxLen256(value))
    override val identityName: Optional[XmlStringMaxLen256] =
      zio.aws.core.internal
        .optionalFromNullable(impl.identityName())
        .map(value => zio.aws.emr.model.primitives.XmlStringMaxLen256(value))
    override val identityType: zio.aws.emr.model.IdentityType =
      zio.aws.emr.model.IdentityType.wrap(impl.identityType())
    override val sessionPolicyArn: XmlStringMaxLen256 =
      zio.aws.emr.model.primitives.XmlStringMaxLen256(impl.sessionPolicyArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.CreateStudioSessionMappingRequest
  ): zio.aws.emr.model.CreateStudioSessionMappingRequest.ReadOnly = new Wrapper(
    impl
  )
}
